==> hermes-6.0.3.13.rec2.tar.gz: hermes-6.0.3.13.rec2/app/lib/notifications_center/user.rb <==
module NotificationsCenter
  class User < Base
    KEYS = NOTIFICATION_KEYS[:user]

    def initialize(*arg)
      super
      @user = @instance.notifiable
      @request = Hermes::HousingRequest.order_by(created_at: :desc).find_by(user_id: @user.id)
    end

    def email 
      case @key
      when KEYS[:new_reserved_offer], KEYS[:entity_validation_accepted], KEYS[:entity_validation_refused]
        find_email_applicant_used_for_siret
      when KEYS[:new_published_offer]
        find_email_on_request
      else
        @user.email
      end
    end 

    def find_email_applicant_used_for_siret
      return find_email_on_request if @request.applicant_used_for_siret_email.blank?
      
      @request.applicant_used_for_siret_email
    end

    def find_email_on_request
      return @user.email if @request.requester_email.blank?

      @request.requester_email
    end
    
    def full_name
      case @key
      when KEYS[:new_reserved_offer], KEYS[:entity_validation_accepted], KEYS[:entity_validation_refused]
        find_full_name_applicant_used_for_siret
      when KEYS[:new_published_offer]
        find_full_name_on_request
      else
        @user.full_name
      end
    end 

    def find_full_name_applicant_used_for_siret
      return find_full_name_on_request if @request.applicant_used_for_siret_lastname.blank?
      
      "#{@request.applicant_used_for_siret_firstname&.capitalize} #{@request.applicant_used_for_siret_lastname&.downcase.capitalize}"
    end 
    
    def find_full_name_on_request
      return @user.full_name if @request.requester_lastname.blank?
      
      "#{@request.requester_firstname&.capitalize} #{@request.requester_lastname&.downcase.capitalize}"
    end 

    def title
      case @key        
      when KEYS[:create]
        "#{NAME} - Création de votre compte"
      when KEYS[:new_reserved_offer]
        "Action Logement Services AL'In Logement exclusif #{@request.entity&.title}"
      when KEYS[:new_published_offer]
        "Action Logement AL'in_De nouvelles offres sont disponibles"
      when KEYS[:application_refusal], KEYS[:application_offer_taken_back], KEYS[:application_not_selected]
        "Action Logement AL'in_Information sur votre candidature"
      when KEYS[:entity_validation_accepted]
        "Action Logement Services _ AL'In_Demande validée"
      when KEYS[:entity_validation_refused]
        "Action Logement Services _ AL'In_Demande refusée par l'entreprise"
      when KEYS[:requests_to_approve]
        "Action Logement Services _ AL'In_Demande en attente de validation"
      else
        ''
      end
    end

    def format_date_mail(date)
      return date.strftime("%d/%m/%Y")
    end

    def capitalized_full_name
      @instance.datas[:first_name].capitalize() + " " + @instance.datas[:last_name].upcase
    end

    def show_anulation_link
      case @key          
      when KEYS[:new_published_offer],KEYS[:new_reserved_offer]
        return true
      else
        return false
      end
    end

    def body
      case @key        
      when KEYS[:create]
        username = @instance.datas[:username]
        "
          Nous vous confirmons votre inscription sur votre plateforme de demande de logement.\n
          Votre identifiant  : #{username}
        "
      when KEYS[:application_refusal]
        str = "
        <table>
          <tbody>
                <tr>
                  <td #{td_padding}>
                    Après examen de votre candidature par la commission d'attribution du bailleur sur le logement situé à #{@instance.datas[:district]}, nous vous informons que celle-ci n'y a pas donné une suite favorable.
                  </td>
                </tr>
                <tr>
                  <td #{td_padding}>
                    Nous vous rappelons que seule la commission d'attribution du bailleur, indépendante d'Action Logement, est compétente pour désigner le candidat retenu.
                  </td>
                </tr>
                <tr>
                  <td #{td_padding}>
                    Nous vous invitons dès à présent à vous rendre sur votre espace AL’in afin de candidater à de nouvelles offres répondant à vos critères
                  </td>
                </tr>
              </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
      when KEYS[:application_not_selected]
        str = "
        <table>
          <tbody>
                <tr>
                  <td #{td_padding}>
                    Après étude de votre candidature sur le logement situé à #{@instance.datas[:district]}, nous vous informons que votre dossier n’a pas été transmis au bailleur.
                  </td>
                </tr>
                <tr>
                  <td #{td_padding}>
                    Sur l’ensemble des candidatures retenues, et comme le prévoit la réglementation, seuls trois dossiers ont été présentés à la commission d’attribution du bailleur. Nous vous rappelons que seule la commission d'attribution du bailleur, indépendante d'Action Logement, est compétente pour désigner le candidat retenu.
                  </td>
                </tr>
                <tr>
                  <td #{td_padding}>
                    Nous vous invitons dès à présent à vous rendre sur votre espace AL’in afin de candidater à de nouvelles offres de logements.
                  </td>
                </tr>
              </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
      when KEYS[:application_offer_taken_back]
        str = "
        <table>
          <tbody>
              <tr>
                <td #{td_padding}>Nous vous informons que le logement n° #{@instance.datas[:external_ref]} situé à #{@instance.datas[:district]}, pour lequel vous avez déposé une candidature le #{@instance.datas[:applicated_at]}, n'est plus disponible. Le bailleur ayant annulé la mise à disposition, nous ne pouvons donc plus vous le proposer. Nous vous invitons dès maintenant à vous rendre sur votre espace, afin de consulter nos offres.
                Découvrez dès maintenant de nouvelles offres susceptibles de vous intéresser.</td>
              </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
      when KEYS[:new_published_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>De nouvelles offres de logements sont disponibles sur votre plateforme AL’in.</td>
            </tr>
            <tr>
            <td #{td_padding}>Consultez les offres susceptibles de vous intéresser et candidatez. Ces offres sont disponibles pendant une durée limitée, qui peut aller de 24h à 7 jours maximum.</td>
          </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
        str
      when KEYS[:new_reserved_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>De nouvelles offres de logement sont disponibles sur votre plateforme AL'in : ces logements sont exclusivement proposés aux salariés de votre entreprise.</td>
            </tr>
            <tr>
              <td #{td_padding}>Consultez les offres susceptibles de vous intéresser et candidatez. Vos offres privilèges sont disponibles pendant une durée limitée, qui peut aller de 24h à 7 jours maximum.</td>
            </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids], 1, "new_reserved_offer_alt_img_url")
        str += "</table></tbody>"
        str += "<table><tbody><tr><td style='padding: 8px;'>Nous vous invitons à consulter toutes les offres disponibles en ligne.</td></tr></table></tbody>"
        str
      when KEYS[:entity_validation_accepted]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>Nous avons le plaisir de vous informer que votre demande de logement sur AL'in a été validée par votre employeur.</td>
            </tr>
            <tr>
              <td #{td_padding}>Vous pouvez vous rendre sur votre espace <a target='_blank' #{url_content_style} href='https://al-in.fr'>www.al-in.fr</a> pour consulter les offres correspondant à votre profil.</td>
            </tr>
          </tbody>
        </table>"
      when KEYS[:entity_validation_refused]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>Nous vous informons que votre demande de logement sur AL'in a été refusée par votre employeur.</td>
            </tr>
            <tr>
              <td #{td_padding}>Si vous souhaitez connaître le motif de ce refus, nous vous invitons à vous rapprocher de votre service des ressources humaines ou de votre service logement.</td>
            </tr>
          </tbody>
        </table>"
      when KEYS[:requests_to_approve]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>Nous vous informons que des salariés de votre entreprise se sont enregistrés sur <a target='_blank' #{url_content_style} href='https://al-in.fr'>www.al-in.fr</a> et que leurs demandes sont en attente de validation de votre part. .</td>
            </tr>
            <tr> 
              <td #{td_padding}>Nous vous invitons dès maintenant à vous rendre sur l'espace de votre entreprise pour nous faire part de votre décision concernant de ces nouvelles demandes.</td>
            </tr>
            <tr>
              <td #{td_padding}>Votre Conseiller Relation Entreprises se tient à votre disposition pour plus d'informations.</td>
            </tr>
          </tbody>
        </table>"
      else
        ''
      end
    end

    def print_offer_list(offers_ids, picture_number = 0, alt_image_url = 'default_offer_alt_img_url')
      str = ''
      offers_ids.each do |offer_id|
        offer = Hermes::HousingOffer.find(offer_id)
        url = "#{HERMES_CONFIG["frontend_url"]}/#/fiche-logement/#{offer.id}?mail=true"
        str += "
        <tr style='vertical-align: top;'>
          <td style='padding: 8px 32px 8px 0;'>
            <a href='#{url}' target='_blank' style='display: block; width: 160px; height: 100px; background-image: url(#{HERMES_CONFIG[alt_image_url]}); background-size: 100% 100%;'>
              <img src='#{offer.picture_for_email(picture_number)}' alt=' ' style='width: 100%; height: 100%; object-fit: cover;'/>
            </a>
          </td>
          <td style='padding: 8px;'>
            <div style='height: 84px;'>
              <b>#{offer.district} (#{offer.department}) - #{offer.surface}m² - #{offer.typology}</b> <br/>
              #{offer.rent_with_charges} € 
            </div>
            <a href='#{url}' #{url_content_style}>En savoir plus</a>
          </td>
        </tr>
        "
      end
      str
    end

    def actions
      case @key          
        when KEYS[:create]
          {
            title: 'Me connecter',
            link: '#connexion-demandeur'
          }
        when KEYS[:application_refusal], KEYS[:application_offer_taken_back],KEYS[:new_published_offer],KEYS[:new_reserved_offer], KEYS[:application_not_selected]
          {
            title: 'Voir toutes les offres',
            link: '#/HomeSalarie?mail=true'
          }
        else
          nil
      end
    end

    def header_text
      case @key
      when KEYS[:new_reserved_offer], KEYS[:new_published_offer] 
        "
          Des nouvelles offres sont disponibles <br/>
        "
      else
        ""
      end 
    end 

    def unsubscribe_link
      case @key
      when KEYS[:new_published_offer], KEYS[:new_reserved_offer]
        '<a style="color:rgb(0, 0, 238)" href="https://als-hermes-entreprise-rec.be-idys.com/#/modif-account?mail=true" target="_blank">
          <u>Annuler l\'abonnement à nos emails</u>
        </a>
        <br />
        '
      else
        ""
      end 
    end

    private 

    def url_content_style
      "style='color:rgb(0, 0, 238); text-decoration: underline; bottom: 0; left: 0;'"
    end 

    def td_padding
      "style='padding: 8px 0;'"
    end 
  end
end

==> hermes-6.0.3.15.rec2.tar.gz: hermes-6.0.3.15.rec2/app/lib/notifications_center/user.rb <==
module NotificationsCenter
  class User < Base
    KEYS = NOTIFICATION_KEYS[:user]

    def initialize(*arg)
      super
      @user = @instance.notifiable
      @request = Hermes::HousingRequest.order_by(created_at: :desc).find_by(user_id: @user.id)
    end

    def email 
      case @key
      when KEYS[:new_reserved_offer], KEYS[:entity_validation_accepted], KEYS[:entity_validation_refused]
        find_email_applicant_used_for_siret
      when KEYS[:new_published_offer]
        find_email_on_request
      else
        @user.email
      end
    end 

    def find_email_applicant_used_for_siret
      return find_email_on_request if @request.applicant_used_for_siret_email.blank?
      
      @request.applicant_used_for_siret_email
    end

    def find_email_on_request
      return @user.email if @request.requester_email.blank?

      @request.requester_email
    end
    
    def full_name
      case @key
      when KEYS[:new_reserved_offer], KEYS[:entity_validation_accepted], KEYS[:entity_validation_refused]
        find_full_name_applicant_used_for_siret
      when KEYS[:new_published_offer]
        find_full_name_on_request
      else
        @user.full_name
      end
    end 

    def find_full_name_applicant_used_for_siret
      return find_full_name_on_request if @request.applicant_used_for_siret_lastname.blank?
      
      "#{@request.applicant_used_for_siret_firstname&.capitalize} #{@request.applicant_used_for_siret_lastname&.downcase.capitalize}"
    end 
    
    def find_full_name_on_request
      return @user.full_name if @request.requester_lastname.blank?
      
      "#{@request.requester_firstname&.capitalize} #{@request.requester_lastname&.downcase.capitalize}"
    end 

    def title
      case @key        
      when KEYS[:create]
        "#{NAME} - Création de votre compte"
      when KEYS[:new_reserved_offer]
        "Action Logement Services AL'In Logement exclusif #{@request.entity&.title}"
      when KEYS[:new_published_offer]
        "Action Logement AL'in_De nouvelles offres sont disponibles"
      when KEYS[:application_offer_taken_back], KEYS[:application_not_selected]
        "Action Logement AL'in_Information sur votre candidature"
      when KEYS[:entity_validation_accepted]
        "Action Logement Services _ AL'In_Demande validée"
      when KEYS[:entity_validation_refused]
        "Action Logement Services _ AL'In_Demande refusée par l'entreprise"
      when KEYS[:requests_to_approve]
        "Action Logement Services _ AL'In_Demande en attente de validation"
      else
        ''
      end
    end

    def format_date_mail(date)
      return date.strftime("%d/%m/%Y")
    end

    def capitalized_full_name
      @instance.datas[:first_name].capitalize() + " " + @instance.datas[:last_name].upcase
    end

    def show_anulation_link
      case @key          
      when KEYS[:new_published_offer],KEYS[:new_reserved_offer]
        return true
      else
        return false
      end
    end

    def body
      case @key        
      when KEYS[:create]
        username = @instance.datas[:username]
        "
          Nous vous confirmons votre inscription sur votre plateforme de demande de logement.\n
          Votre identifiant  : #{username}
        "
      when KEYS[:application_not_selected]
        str = "
        <table>
          <tbody>
                <tr>
                  <td #{td_padding}>
                    Après étude de votre candidature sur le logement situé à #{@instance.datas[:district]}, nous vous informons que votre dossier n’a pas été transmis au bailleur.
                  </td>
                </tr>
                <tr>
                  <td #{td_padding}>
                    Sur l’ensemble des candidatures retenues, et comme le prévoit la réglementation, seuls trois dossiers ont été présentés à la commission d’attribution du bailleur. Nous vous rappelons que seule la commission d'attribution du bailleur, indépendante d'Action Logement, est compétente pour désigner le candidat retenu.
                  </td>
                </tr>
                <tr>
                  <td #{td_padding}>
                    Nous vous invitons dès à présent à vous rendre sur votre espace AL’in afin de candidater à de nouvelles offres de logements.
                  </td>
                </tr>
              </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
      when KEYS[:application_offer_taken_back]
        str = "
        <table>
          <tbody>
              <tr>
                <td #{td_padding}>Nous vous informons que le logement n° #{@instance.datas[:external_ref]} situé à #{@instance.datas[:district]}, pour lequel vous avez déposé une candidature le #{@instance.datas[:applicated_at]}, n'est plus disponible. Le bailleur ayant annulé la mise à disposition, nous ne pouvons donc plus vous le proposer. Nous vous invitons dès maintenant à vous rendre sur votre espace, afin de consulter nos offres.
                Découvrez dès maintenant de nouvelles offres susceptibles de vous intéresser.</td>
              </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
      when KEYS[:new_published_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>De nouvelles offres de logements sont disponibles sur votre plateforme AL’in.</td>
            </tr>
            <tr>
            <td #{td_padding}>Consultez les offres susceptibles de vous intéresser et candidatez. Ces offres sont disponibles pendant une durée limitée, qui peut aller de 24h à 7 jours maximum.</td>
          </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
        str
      when KEYS[:new_reserved_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>De nouvelles offres de logement sont disponibles sur votre plateforme AL'in : ces logements sont exclusivement proposés aux salariés de votre entreprise.</td>
            </tr>
            <tr>
              <td #{td_padding}>Consultez les offres susceptibles de vous intéresser et candidatez. Vos offres privilèges sont disponibles pendant une durée limitée, qui peut aller de 24h à 7 jours maximum.</td>
            </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        str += print_offer_list( @instance.datas[:offer_ids], 1, "new_reserved_offer_alt_img_url")
        str += "</table></tbody>"
        str += "<table><tbody><tr><td style='padding: 8px;'>Nous vous invitons à consulter toutes les offres disponibles en ligne.</td></tr></table></tbody>"
        str
      when KEYS[:entity_validation_accepted]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>Nous avons le plaisir de vous informer que votre demande de logement sur AL'in a été validée par votre employeur.</td>
            </tr>
            <tr>
              <td #{td_padding}>Vous pouvez vous rendre sur votre espace <a target='_blank' #{url_content_style} href='https://al-in.fr'>www.al-in.fr</a> pour consulter les offres correspondant à votre profil.</td>
            </tr>
          </tbody>
        </table>"
      when KEYS[:entity_validation_refused]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>Nous vous informons que votre demande de logement sur AL'in a été refusée par votre employeur.</td>
            </tr>
            <tr>
              <td #{td_padding}>Si vous souhaitez connaître le motif de ce refus, nous vous invitons à vous rapprocher de votre service des ressources humaines ou de votre service logement.</td>
            </tr>
          </tbody>
        </table>"
      when KEYS[:requests_to_approve]
        str = "
        <table>
          <tbody>
            <tr>
              <td #{td_padding}>Nous vous informons que des salariés de votre entreprise se sont enregistrés sur <a target='_blank' #{url_content_style} href='https://al-in.fr'>www.al-in.fr</a> et que leurs demandes sont en attente de validation de votre part. .</td>
            </tr>
            <tr> 
              <td #{td_padding}>Nous vous invitons dès maintenant à vous rendre sur l'espace de votre entreprise pour nous faire part de votre décision concernant de ces nouvelles demandes.</td>
            </tr>
            <tr>
              <td #{td_padding}>Votre Conseiller Relation Entreprises se tient à votre disposition pour plus d'informations.</td>
            </tr>
          </tbody>
        </table>"
      else
        ''
      end
    end

    def print_offer_list(offers_ids, picture_number = 0, alt_image_url = 'default_offer_alt_img_url')
      str = ''
      offers_ids.each do |offer_id|
        offer = Hermes::HousingOffer.find(offer_id)
        url = "#{HERMES_CONFIG["frontend_url"]}/#/fiche-logement/#{offer.id}?mail=true"
        str += "
        <tr style='vertical-align: top;'>
          <td style='padding: 8px 32px 8px 0;'>
            <a href='#{url}' target='_blank' style='display: block; width: 160px; height: 100px; background-image: url(#{HERMES_CONFIG[alt_image_url]}); background-size: 100% 100%;'>
              <img src='#{offer.picture_for_email(picture_number)}' alt=' ' style='width: 100%; height: 100%; object-fit: cover;'/>
            </a>
          </td>
          <td style='padding: 8px;'>
            <div style='height: 84px;'>
              <b>#{offer.district} (#{offer.department}) - #{offer.surface}m² - #{offer.typology}</b> <br/>
              #{offer.rent_with_charges} € 
            </div>
            <a href='#{url}' #{url_content_style}>En savoir plus</a>
          </td>
        </tr>
        "
      end
      str
    end

    def actions
      case @key          
        when KEYS[:create]
          {
            title: 'Me connecter',
            link: '#connexion-demandeur'
          }
        when KEYS[:application_offer_taken_back],KEYS[:new_published_offer],KEYS[:new_reserved_offer], KEYS[:application_not_selected]
          {
            title: 'Voir toutes les offres',
            link: '#/HomeSalarie?mail=true'
          }
        else
          nil
      end
    end

    def header_text
      case @key
      when KEYS[:new_reserved_offer], KEYS[:new_published_offer] 
        "
          Des nouvelles offres sont disponibles <br/>
        "
      else
        ""
      end 
    end 

    def unsubscribe_link
      case @key
      when KEYS[:new_published_offer], KEYS[:new_reserved_offer]
        '<a style="color:rgb(0, 0, 238)" href="https://als-hermes-entreprise-rec.be-idys.com/#/modif-account?mail=true" target="_blank">
          <u>Annuler l\'abonnement à nos emails</u>
        </a>
        <br />
        '
      else
        ""
      end 
    end

    private 

    def url_content_style
      "style='color:rgb(0, 0, 238); text-decoration: underline; bottom: 0; left: 0;'"
    end 

    def td_padding
      "style='padding: 8px 0;'"
    end 
  end
end
